/***********************************************************************************************************************
 *
 * SolidBlue - open source safe data
 * Copyright (C) 2011-2012 by Tidalwave s.a.s. (http://tidalwave.it)
 *
 ***********************************************************************************************************************
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations under the License.
 *
 ***********************************************************************************************************************
 *
 * WWW: http://solidblue.tidalwave.it
 * SCM: https://bitbucket.org/tidalwave/solidblue-src
 *
 **********************************************************************************************************************/
package it.tidalwave.actor.impl.io.filescan;

import javax.annotation.Nonnull;
import javax.annotation.concurrent.ThreadSafe;
import java.io.IOException;
import java.nio.file.DirectoryStream;
import java.nio.file.Files;
import java.nio.file.Path;
import it.tidalwave.actor.annotation.Actor;
import it.tidalwave.actor.annotation.ListensTo;
import it.tidalwave.actor.io.filescan.FileDiscoveredMessage;
import it.tidalwave.actor.io.filescan.FileScanRequestMessage;
import lombok.Cleanup;
import lombok.extern.slf4j.Slf4j;

/***********************************************************************************************************************
 * 
 * @stereotype Actor
 * 
 * An actor for discovering files in a given folder.
 * 
 * @author  Fabrizio Giudici
 * @version $Id$
 *
 **********************************************************************************************************************/
@Actor @ThreadSafe @Slf4j
public class FileObjectDiscoveryActor
  {
    public void onScanRequested (final @ListensTo @Nonnull FileScanRequestMessage message) 
      throws IOException
      {
        log.debug("onScanRequested({})", message);
        
        @Cleanup final DirectoryStream<Path> ds = Files.newDirectoryStream(message.getFolder(), message.getFilter());

        for (final Path child : ds)
          {
            (child.toFile().isDirectory() ? FileScanRequestMessage.forFolder(child).withFilter(message.getFilter()) 
                                          : FileDiscoveredMessage.forPath(child))
                                          .send();
          }
      }
  }
