/***********************************************************************************************************************
 *
 * SolidBlue - open source safe data
 * Copyright (C) 2011-2012 by Tidalwave s.a.s. (http://tidalwave.it)
 *
 ***********************************************************************************************************************
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations under the License.
 *
 ***********************************************************************************************************************
 *
 * WWW: http://solidblue.tidalwave.it
 * SCM: https://bitbucket.org/tidalwave/solidblue-src
 *
 **********************************************************************************************************************/
package it.tidalwave.integritychecker.impl.fingerprint;

import javax.annotation.Nonnull;
import javax.annotation.concurrent.ThreadSafe;
import java.security.MessageDigest;
import java.security.NoSuchAlgorithmException;
import it.tidalwave.actor.annotation.Actor;
import it.tidalwave.actor.annotation.ListensTo;
import it.tidalwave.integritychecker.fingerprint.Fingerprint;
import it.tidalwave.integritychecker.fingerprint.FingerprintComputeRequest;
import it.tidalwave.integritychecker.fingerprint.FingerprintComputedMessage;
import lombok.extern.slf4j.Slf4j;

/***********************************************************************************************************************
 * 
 * @stereotype Actor
 * 
 * An actor for computing the fingerprint of a file.
 * 
 * @author  Fabrizio Giudici
 * @version $Id$
 *
 **********************************************************************************************************************/
@Actor @ThreadSafe @Slf4j
public class FingerprintComputerActor
  {
    public void onFileContentsAvailable (final @ListensTo @Nonnull FingerprintComputeRequest message) 
      throws NoSuchAlgorithmException 
      {
        final String algorithm = "MD5";
        final MessageDigest digestComputer = MessageDigest.getInstance(algorithm);
        digestComputer.update(message.getContent());
        final Fingerprint fingerprint = new Fingerprint(algorithm, digestComputer.digest());
        FingerprintComputedMessage.forPath(message.getPath()).withFingerprint(fingerprint).send();
      }
  }
